@@ -10,6 +10,7 @@ import signal
 import string
 import subprocess
 import traceback
+import colorama
 from datetime import datetime
 from functools import wraps
 from pathlib import Path
@@ -377,6 +378,7 @@ class OnKill:
     _funcs: PriorityQueue[Tuple[int, Callable[[], None]]] = PriorityQueue()
     _min_priority = 0
     _already_killed = False
+    _pids_to_kill: List[int] = []
 
     def __init__(self) -> None:
         signal.signal(signal.SIGINT, OnKill.exit)
@@ -402,6 +404,14 @@ class OnKill:
 
         if OnKill._already_killed:
             print("Alright, stay calm. I am skipping cleanup and exiting!")
+
+            # Kill remaining processes
+            for pid in OnKill._pids_to_kill:
+                try:
+                    os.kill(pid, 9)
+                except Exception:
+                    pass
+
             os._exit(sig)
 
         OnKill._already_killed = True
@@ -413,6 +423,10 @@ class OnKill:
         for _ in range(OnKill._funcs.qsize()):
             OnKill._funcs.get_nowait()[1]()
 
+    @staticmethod
+    def add_pid(pid: int) -> None:
+        OnKill._pids_to_kill.append(pid)
+
 
 def on_kill(priority: Optional[int] = None) -> Callable[[Any], Any]:
     def decorator(function: Any) -> Any:
@@ -626,6 +640,7 @@ if is_first_time:
     if is_autorun:
         exit(1)
 
+colorama.init()
 startup()
 OnKill()
 database_helper = DatabaseHelper()
